@@ -1,7 +1,10 @@
 ##########################################################################
-# These functions are 
-# Copyright (C) 2014-2018 V. Miranda & T. W. Yee, University of Auckland.
+# These functions are
+# Copyright (C) 2014-2023 V. Miranda & T. Yee
+# Auckland University of Technology & University of Auckland
 # All rights reserved.
+#
+# Links renamed on Jan-2019 conforming with VGAM_1.1-0
 
 
 
@@ -19,18 +22,18 @@ poissonTSff.control <- function(criterion = "loglikelihood",
 
 
 
-poissonTSff <- function(Order = c(1, 1),
-                        link = "loge",
+poissonTSff <- function(link = "loglink",
+                        interventions = list(),
                         lagged.fixed.obs   = NULL,
                         lagged.fixed.means = NULL,
-                        interventions = list(),
-                        init.p.ARMA = NULL,
                         f.transform.Y = NULL,
                         transform.lambda = FALSE,
+                        init.p.ARMA = NULL,
                         imethod = 1,
                         dispersion = 1) {
   
   ### Default from poissonff, April-2017
+  Order <- c(0, 0)
   earg.link   <- FALSE
   type.fitted <- c("mean", "quantiles")[1]
   percentiles <- c(25, 50, 75)
@@ -41,10 +44,10 @@ poissonTSff <- function(Order = c(1, 1),
   bred <- FALSE
   imu  <- NULL
   zero <- NULL
-  link <- match.arg(link, c("identitylink", "negloge",
-                            "reciprocal", "loge"))[1]
-  
-  if (length(f.transform.Y) && !is.function(f.transform.Y))
+  link <- match.arg(link, c("identitylink", "negloglink",
+                            "reciprocallink", "loglink"))[1]
+
+    if (length(f.transform.Y) && !is.function(f.transform.Y))
     stop("Wrong input for argument 'f.transform.Y'. Must be a function.",
          " Enter NULL for the identity function.")
   
@@ -84,6 +87,15 @@ poissonTSff <- function(Order = c(1, 1),
   ord1 <- max(fixed.obs, Order[1])
   ord2 <- max(fixed.mean, Order[2])
   
+  if ((ord1 == 0) && (ord2 == 0))
+    stop("Refer to poissonff() to fit an ordinary Poisson dist. ")
+  
+  if (!length(fixed.obs))
+    stop("Wrong input for argument 'lagged.fixed.obs'")
+
+  if (!length(fixed.mean))
+    stop("Wrong input for argument 'lagged.fixed.mean'")
+  
   if (length(fixed.obs) && !is.vector(fixed.obs))
     stop("Wrong input for argument 'lagged.fixed.obs'.")
   
@@ -92,11 +104,13 @@ poissonTSff <- function(Order = c(1, 1),
   
   if (length(fixed.obs) && 
        !Is.Numeric(fixed.obs, Nnegative = TRUE, isInteger = TRUE))
-    stop("Wrong input for argument 'lagged.fixed.obs'")
+    stop("Enter only admissible values for 'lageed.fixed.obs'.")
+    
   
   if (length(fixed.mean) &&
       !Is.Numeric(fixed.mean, Nnegative = TRUE, isInteger = TRUE))
-    stop("Wrong input for argument 'lagged.fixed.mean'")
+    stop("Enter only admissible values for 'lageed.fixed.means'.")
+    
   
   if (earg.link) {
     earg <- link
@@ -135,11 +149,11 @@ poissonTSff <- function(Order = c(1, 1),
       #  stop("Currently, this family function only handles ",
       #       "intercept-only models.")
       
-      if (NCOL(y) > 2)
+      if (NCOL(y) > 1)
         stop("Currently, only univariate time series handled.")
       
       iniOrd <- if (length( .init.p )) .init.p else
-        max(25, .ord1 + .ord2 + 1)  # Dec 2017, Old is init.p = 10
+        max(10, .ord1 + .ord2 + 1)  # Dec 2017, Old is init.p = 10
       nn <- NROW(y)
       
       temp.pd <- data.frame(y = y, WN.lags(y = cbind(y), 
@@ -206,7 +220,7 @@ poissonTSff <- function(Order = c(1, 1),
                            drop = FALSE]
         
         if ( .flam ) {
-          x2.mat <- if (identical( .link, "loge")) 
+          x2.mat <- if (identical( .link, "loglink")) 
                      theta2eta(x2.mat + 1, .link , .earg) else
                        theta2eta(x2.mat, .link , .earg)
           if (!identical( .link, "identitylink")) 
@@ -270,8 +284,7 @@ poissonTSff <- function(Order = c(1, 1),
         list.names[[ii]] <- ii
       attr(x.matrix, "assign") <- list.names
       x <- x.matrix
-      
-      
+
     }), list( .ord1 = ord1 , .ord2 = ord2 , .Order = Order , 
               .fixed.mean = fixed.mean , .fixed.obs = fixed.obs ,
               .link = link , .earg = earg , .interv = interv ,
@@ -310,7 +323,7 @@ poissonTSff <- function(Order = c(1, 1),
                .bred = bred ))),
       
       
-   #   deviance = eval(substitute(
+  #   deviance = eval(substitute(
   #      function(mu, y, w, residuals = FALSE, eta, extra = NULL,
   #               summation = TRUE) {
   #        mupo <- eta2theta(eta, link = .link , earg = .earg )
@@ -347,7 +360,7 @@ poissonTSff <- function(Order = c(1, 1),
      
      M <- ncoly <- ncol(y)
      
-     assign("CQO.FastAlgorithm", ( .link == "loge"), envir = VGAMenv)
+     assign("CQO.FastAlgorithm", ( .link == "loglink"), envir = VGAMenv)
      
      old.name <- "mu"
      new.name <- "lambda"
@@ -545,7 +558,7 @@ poissonTSff <- function(Order = c(1, 1),
      }
      
      
-     answer <- if ( .link == "loge" && (any(mupo < .Machine$double.eps))) {
+     answer <- if ( .link == "loglink" && (any(mupo < .Machine$double.eps))) {
        c(w) * (yBRED - mupo)
      } else {
        lambda <- mupo
@@ -563,7 +576,7 @@ poissonTSff <- function(Order = c(1, 1),
   
   
    weight = eval(substitute(expression({
-     if ( .link == "loge" && (any(mupo < .Machine$double.eps))) {
+     if ( .link == "loglink" && (any(mupo < .Machine$double.eps))) {
        tmp600 <- mupo
        tmp600[tmp600 < .Machine$double.eps] <- .Machine$double.eps
        c(w) * tmp600
